#
# spec file for package gr-fcdproplus
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libgnuradio-fcdproplus
%define sover 3_8_0
Name:           gr-fcdproplus
Version:        3.8~git.20200811
Release:        bp155.2.17
Summary:        Fcdproplus Linux addon for gnuradio
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/dl1ksv/gr-fcdproplus
#Git-Clone:     https://github.com/dl1ksv/gr-fcdproplus.git
Source:         %{name}-%{version}.tar.xz
Source1:        gr-fcdproplus.rules
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gnuradio-devel
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libhidapi-devel
BuildRequires:  libmpir-devel
BuildRequires:  orc
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(portaudio-2.0)
%if 0%{?suse_version} <= 1500
BuildRequires:  python3-six
%endif

%description
gr-fcdproplus is a Linux addon for gnuradio to implement a FUNcube Dongle
Pro+ source. It autodetects the correct soundcard from /proc/asound/cards.
This idea was taken from the osmosdr drivers.
To control the device, the hidraw code of the HID API is used.

%package -n %{libname}%{sover}
Summary:        Fcdproplus Linux addon for gnuradio
Group:          System/Libraries
Recommends:     fcdproplus-udev

%description -n %{libname}%{sover}
gr-fcdproplus is a Linux addon for gnuradio to implement a FUNcube Dongle
Pro+ source. It autodetects the correct soundcard from /proc/asound/cards.
This idea was taken from the osmosdr drivers.
To control the device, the hidraw code of the HID API is used.

%package -n %{libname}-devel
Summary:        Development files for the fcdproplus gnuradio Linux addon
Group:          Development/Libraries/Other
Requires:       %{libname}%{sover} = %{version}

%description -n %{libname}-devel
gr-fcdproplus is a Linux addon for gnuradio to implement a FUNcube Dongle
Pro+ source. It autodetects the correct soundcard from /proc/asound/cards.
This idea was taken from the osmosdr drivers.
To control the device, the hidraw code of the HID API is used.

%package -n python-gr-fcdproplus
Summary:        Python bindings for gr-fcdproplus
Group:          Development/Libraries/Other
Requires:       %{libname}%{sover} = %{version}

%description -n python-gr-fcdproplus
gr-fcdproplus is a Linux addon for gnuradio to implement a FUNcube Dongle
Pro+ source. It autodetects the correct soundcard from /proc/asound/cards.
This idea was taken from the osmosdr drivers.
To control the device, the hidraw code of the HID API is used.

%package -n fcdproplus-udev
Summary:        Udev rules for funcube dongle pro+ devices
Group:          Hardware/Other
Requires(pre):  pwdutils
BuildArch:      noarch

%description -n fcdproplus-udev
Udev rules for funcube dongle pro+ devices.

%package devel-doc
Summary:        Documentation for gnuradio-osmosdr
Group:          Documentation/Other
Requires:       %{libname}-devel
BuildArch:      noarch

%description devel-doc
Documentation for gr-fcdproplus module for GNU Radio.

%prep
%setup -q

%build
%cmake \
    -DENABLE_DOXYGEN=1 \
    -DCMAKE_SHARED_LINKER_FLAGS=""
make %{?_smp_mflags}

%install
%cmake_install
%fdupes %{buildroot}/%{_prefix}

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}/%{_datadir}/doc/%{name} %{buildroot}%{_docdir}

install -Dm 0644 "%{SOURCE1}" %{buildroot}%{_udevrulesdir}/10-gr-fcdproplus.rules

%post   -n %{libname}%{sover} -p /sbin/ldconfig
%postun -n %{libname}%{sover} -p /sbin/ldconfig

%post -n fcdproplus-udev
%udev_rules_update

%postun -n fcdproplus-udev
%udev_rules_update

%files
%license COPYING
%doc README.md
%{_datadir}/gnuradio/grc/blocks/*.yml
%exclude %{_docdir}/%{name}/html
%exclude %{_docdir}/%{name}/xml

%files -n %{libname}%{sover}
%{_libdir}/libgnuradio-fcdproplus.so.*

%files -n %{libname}-devel
%{_includedir}/fcdproplus
%{_libdir}/libgnuradio-fcdproplus.so
%{_libdir}/cmake/gr-fcdproplus
%{_libdir}/pkgconfig/gnuradio-fcdproplus.pc

%files -n python-gr-fcdproplus
%{python3_sitearch}/fcdproplus

%files -n fcdproplus-udev
%{_udevrulesdir}/10-gr-fcdproplus.rules

%files devel-doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/html
%{_docdir}/%{name}/xml

%changelog
* Wed Sep 23 2020 Martin Hauke <mardnh@gmx.de>
- Add python3-six as BR conditionally for Leap systems
* Fri Aug 28 2020 Martin Hauke <mardnh@gmx.de>
- Fix _service file
* Wed Aug 26 2020 matwey.kornilov@gmail.com
- Do not use bundled libhidapi library (Requires: libhidapi-devel)
- Update to version 3.8~git.20200811:
  * Fixed compilation with boost-1.73.0
  * Update README.md
* Thu Sep 19 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.8~git.20190817:
  * Adopting Versioning to gnuradio 3.8 versioning scheme
  * Fixing typo
  * Fixing path error when bundled hidapi is used
  * Updating README
  * Adopt to modern cmake used in gnuradio
  * Intial setup for modern cmake
  * Add FindUSB.cmake as removed in gnuradio
  * Updating fcdpp and adding fcd modules
  * Create MANIFEST.md
  * Find only 3.7 installations
  * Fixing some typos
  * Setting correct block path
  * Handling messages to set frequency
  * Preparing for dealing with messages
  * Initial commit, preparing for 3.8
  * Preparation for gnuradio 3.8
  * Removing unnecessary dependency for gnuradio
* Sun Jun  2 2019 Martin Hauke <mardnh@gmx.de>
- Fix Requires for python-gr-fcdproplus
* Sat Apr  6 2019 Martin Hauke <mardnh@gmx.de>
- Fix Requires for devel-doc
* Sun Mar 24 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to release 3.7.12
  * last release for GNU Radio 3.7
  * library version still 3.7.2
- Fixed build with Boost 1.69
* Wed Jan  9 2019 mardnh@gmx.de
- Create a dedicated subpackage for the udev rules
- Drop udev hacks for {?suse_version} < 1230
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Fix spelling of various brand names.
- Limit fdupes call so it does not cross the /usr boundary.
- Adjust SRPM groups.
* Mon Jun 25 2018 mardnh@gmx.de
- Update to version 3.7+git.20180529:
  * Adopting to Ubuntu gnuradio installation
  * Adding gr-fcdproplus to Core category, improving example
  * Adding search path for Kali Linux
  * Adding lib64 to path in hints
  * Adding search path for raspberry pi
  * Update CMakeLists.txt
  * Some typos
- Add _service file
- Run spec-cleaner
- Fix boost dependencies for Tumbleweed
* Sat Dec  9 2017 wk@ire.pw.edu.pl
- improve boost dependency
* Thu May 25 2017 mardnh@gmx.de
- Use %%cmake macro
* Sat Apr 15 2017 mardnh@gmx.de
- Build development documentation
* Fri Apr 14 2017 mardnh@gmx.de
- Rename %%soname to %%sover to better reflect its use.
- Fix build for all 64-bit platforms
* Mon Feb 22 2016 dl8fcl@t-online.de
- update to version 3.7_git20160222
* Sun Jan 11 2015 dl8fcl@darc.de
- update to version 3.7_git20150111
* Mon Mar 24 2014 dl8fcl@darc.de
- update to version 3.7_git20140324
* Sun Nov  3 2013 lnt-sysadmin@lists.lrz.de
- Changes to spec file:
  * Update udev paths for openSUSE 13.1 and ensure udev rules are
    updated when package is installed / updated / uninstalled.
  * Define %%libname to ease reuse of %%post(un) macros
* Tue Aug 13 2013 dl8fcl@darc.de
- import into build service
